@@ -34,11 +34,13 @@ logger = logging.getLogger('Butterfly.Aliasing')
 
 class ButterflyAliasing(
         telepathy.server.ConnectionInterfaceAliasing,
-        papyon.event.ContactEventInterface):
+        papyon.event.ContactEventInterface,
+        papyon.event.ProfileEventInterface):
 
     def __init__(self):
         telepathy.server.ConnectionInterfaceAliasing.__init__(self)
         papyon.event.ContactEventInterface.__init__(self, self.msn_client)
+        papyon.event.ProfileEventInterface.__init__(self, self.msn_client)
 
     def GetAliasFlags(self):
         return telepathy.constants.CONNECTION_ALIAS_FLAG_USER_SET
@@ -108,6 +110,10 @@ class ButterflyAliasing(
                     update_contact_infos(contact, infos)
                 handle.pending_alias = None
 
+    # papyon.event.ProfileEventInterface
+    def on_profile_display_name_changed(self):
+        self._contact_alias_changed(self.msn_client.profile)
+
     def _get_alias(self, handle_id):
         """Get the alias from one handle id"""
         handle = self.handle(telepathy.HANDLE_TYPE_CONTACT, handle_id)
@@ -133,11 +139,15 @@ class ButterflyAliasing(
 
     @async
     def _contact_alias_changed(self, contact):
-        handle = ButterflyHandleFactory(self, 'contact',
-                contact.account, contact.network_id)
+        alias = None
 
-        alias = contact.infos.get(ContactGeneral.ANNOTATIONS, {}).\
-            get(ContactAnnotations.NICKNAME, None)
+        if contact.account != self.msn_client.profile.account:
+            handle = ButterflyHandleFactory(self, 'contact',
+                contact.account, contact.network_id)
+            alias = contact.infos.get(ContactGeneral.ANNOTATIONS, {}).\
+                get(ContactAnnotations.NICKNAME, None)
+        else:
+            handle = ButterflyHandleFactory(self, 'self')
 
         if alias == "" or alias is None:
             alias = contact.display_name
