@@ -89,14 +89,14 @@ class ButterflyCapabilities(
         self._update_capabilities_calls = []
 
     def AdvertiseCapabilities(self, add, remove):
-        #for caps, specs in add:
-            #if caps == telepathy.CHANNEL_TYPE_STREAMED_MEDIA:
-                #if specs & telepathy.CHANNEL_MEDIA_CAPABILITY_VIDEO:
-                    #self._self_handle.profile.client_id.has_webcam = True
-                    #self._self_handle.profile.client_id.supports_rtc_video = True
-        #for caps in remove:
-            #if caps == telepathy.CHANNEL_TYPE_STREAMED_MEDIA:
-                #self._self_handle.profile.client_id.has_webcam = False
+        for caps, specs in add:
+            if caps == telepathy.CHANNEL_TYPE_STREAMED_MEDIA:
+                if specs & telepathy.CHANNEL_MEDIA_CAPABILITY_VIDEO:
+                    self._self_handle.profile.client_id.has_webcam = True
+                    self._self_handle.profile.client_id.supports_rtc_video = True
+        for caps in remove:
+            if caps == telepathy.CHANNEL_TYPE_STREAMED_MEDIA:
+                self._self_handle.profile.client_id.has_webcam = False
 
         return telepathy.server.ConnectionInterfaceCapabilities.\
             AdvertiseCapabilities(self, add, remove)
@@ -123,9 +123,6 @@ class ButterflyCapabilities(
             self._update_capabilities_calls.append(caps)
             return
 
-        # butterfly voip is disabled, so
-        return
-
         # We only care about voip.
         for client, classes, capabilities in caps:
             video = False
@@ -134,12 +131,15 @@ class ButterflyCapabilities(
                 if channel_class[telepathy.CHANNEL_INTERFACE + '.ChannelType'] == \
                         telepathy.CHANNEL_TYPE_STREAMED_MEDIA:
                     video = True
-                    self._video_clients.append(client)
-                else:
-                    # *Did* it used to support video?
-                    if client in self._video_clients:
-                        self._video_clients.remove(client)
+                    break
 
+            if video and client not in self._video_clients:
+                self._video_clients.append(client)
+            elif not video and client in self._video_clients:
+                # *Did* it used to support video?
+                self._video_clients.remove(client)
+
+        video = (len(self._video_clients) > 0)
         changed = False
 
         # We've got no more clients that support video; remove the cap.
@@ -148,7 +148,8 @@ class ButterflyCapabilities(
             changed = True
 
         # We want video.
-        if video and not self._self_handle.profile.client_id.has_webcam:
+        if video and (not self._self_handle.profile.client_id.has_webcam or
+           not self._self_handle.profile.client_id.supports_rtc_video):
             self._self_handle.profile.client_id.has_webcam = True
             self._self_handle.profile.client_id.supports_rtc_video = True
             changed = True
@@ -257,17 +258,17 @@ class ButterflyCapabilities(
         rcc = None
 
         caps = contact.client_capabilities
-        #if caps.supports_sip_invite:
-            #gen_caps |= telepathy.CONNECTION_CAPABILITY_FLAG_CREATE
-            #gen_caps |= telepathy.CONNECTION_CAPABILITY_FLAG_INVITE
-            #spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_AUDIO
-            #spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_NAT_TRAVERSAL_STUN
+        if caps.supports_sip_invite:
+            gen_caps |= telepathy.CONNECTION_CAPABILITY_FLAG_CREATE
+            gen_caps |= telepathy.CONNECTION_CAPABILITY_FLAG_INVITE
+            spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_AUDIO
+            spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_NAT_TRAVERSAL_STUN
 
-            #if caps.has_webcam:
-                #spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_VIDEO
-                #rcc = self.av_chat_class
-            #else:
-                #rcc = self.audio_chat_class
+            if caps.has_webcam:
+                spec_caps |= telepathy.CHANNEL_MEDIA_CAPABILITY_VIDEO
+                rcc = self.av_chat_class
+            else:
+                rcc = self.audio_chat_class
 
         return gen_caps, spec_caps, rcc
 
