@@ -86,25 +86,27 @@ class ButterflyConnection(telepathy.server.Connection,
             account = unicode(parameters['account'])
             self._server = (parameters['server'].encode('utf-8'), parameters['port'])
 
-            # Build the proxies configurations
             self._proxies = {}
+            self._direct_proxies = [None]
+            self._http_proxies = [None]
+            self._default_http_proxy = None
+            self._default_https_proxy = None
+
+            # Build the proxies configurations
+            self._try_http = parameters['http-method']
             proxy = build_proxy_infos(parameters, 'http')
             if proxy is not None:
-                self._proxies['http'] = proxy
+                self._http_proxies = [proxy]
+                self._default_http_proxy = proxy
             proxy = build_proxy_infos(parameters, 'https')
             if proxy is not None:
-                self._proxies['https'] = proxy
+                self._default_https_proxy = proxy
 
-            self._suggested_proxies = []
-
-            # If the HTTP proxy parameters have been set, don't try any
-            # others proxies automatically.
-            if 'http' not in self._proxies:
-                self._fill_suggested_proxies()
-                self._use_next_proxy()
+            self._fill_suggested_proxies()
+            self._use_next_proxy()
 
             self._manager = weakref.proxy(manager)
-            self._new_client(use_http=parameters['http-method'])
+            self._new_client(use_http=self._try_http)
             self._account = (parameters['account'].encode('utf-8'),
                     parameters['password'].encode('utf-8'))
             self._channel_manager = ButterflyChannelManager(self)
@@ -140,10 +142,11 @@ class ButterflyConnection(telepathy.server.Connection,
         if use_http:
             self._tried_http = True
             self._msn_client = papyon.Client(self._server, self._proxies,
-                papyon.transport.HTTPPollConnection)
+                papyon.transport.HTTPPollConnection, 18)
         else:
             self._tried_http = False
-            self._msn_client = papyon.Client(self._server, self._proxies)
+            self._msn_client = papyon.Client(self._server, self._proxies,
+                version=18)
 
         papyon.event.ClientEventInterface.__init__(self, self._msn_client)
         papyon.event.InviteEventInterface.__init__(self, self._msn_client)
@@ -153,29 +156,60 @@ class ButterflyConnection(telepathy.server.Connection,
         try:
             import libproxy
         except ImportError:
+            logger.warning("Please install libproxy python bindings to enable proxy support.")
             return
 
         factory = libproxy.ProxyFactory()
-        proxies = factory.getProxies('http://gateway.messenger.msn.com/')
 
-        # Remove socks proxies that papyon doesn't support.
-        proxies = [p for p in proxies if p.startswith('http://') or p == 'direct://']
+        # Get DirectConnection proxies
+        proxies = factory.getProxies('none://messenger.msn.com:1863')
+        proxies = [self._parse_proxy(p) for p in proxies]
+        self._direct_proxies = proxies
 
-        if proxies:
-            self._suggested_proxies = proxies
+        # Get HTTP proxies (if not already set by a parameter)
+        if not self._default_http_proxy:
+            proxies = factory.getProxies('http://gateway.messenger.msn.com/')
+            proxies = [self._parse_proxy(p) for p in proxies]
+            self._http_proxies = proxies
+            if len(proxies) > 0:
+                self._default_http_proxy = proxies[0]
+
+        # Get HTTPS proxies (if not already set by a parameter)
+        if not self._default_https_proxy:
+            proxies = factory.getProxies('https://rsi.hotmail.com/rsi/rsi.asmx')
+            proxies = [self._parse_proxy(p) for p in proxies]
+            if len(proxies) > 0:
+                self._default_https_proxy = proxies[0]
 
     def _use_next_proxy(self):
-        if not self._suggested_proxies:
+        if not self._try_http and self._direct_proxies:
+            direct_proxy = self._direct_proxies.pop(0)
+            http_proxy   = self._default_http_proxy
+            https_proxy  = self._default_https_proxy
+        elif self._http_proxies:
+            self._try_http = True
+            direct_proxy = None
+            http_proxy   = self._http_proxies.pop(0)
+            https_proxy  = self._default_https_proxy
+        else:
             return False
 
-        # Use the first one.
-        proxy = self._suggested_proxies.pop(0)
+        self._proxies['direct'] = direct_proxy
+        self._proxies['http']   = http_proxy
+        self._proxies['https']  = https_proxy
 
-        if proxy == 'direct://':
-            if 'http' in self._proxies:
-                del self._proxies['http']
-            return True
+        # Clean proxies (remove None)
+        for conn_type in ('direct', 'http', 'https'):
+            if conn_type not in self._proxies:
+                pass
+            proxy = self._proxies[conn_type]
+            if proxy is None:
+                del self._proxies[conn_type]
+            logger.info('Using %s proxy: %s' % (conn_type, proxy))
 
+        return True
+
+    def _parse_proxy(self, proxy):
         # libproxy documentation states:
         #
         #  * The format of the returned proxy strings are as follows:
@@ -183,12 +217,13 @@ class ButterflyConnection(telepathy.server.Connection,
         #  *   - socks://[username:password@]proxy:port
         #  *   - direct://
         #  etc.
-        #
-        # We've already removed every proxy other than http and
-        # direct, and have dealt with direct, so any other element
-        # will be an HTTP proxy:
 
-        proxy = proxy[len('http://'):]
+        if proxy is None or proxy == "direct://":
+            return None
+
+        index = proxy.find("://")
+        ptype = proxy[0:index]
+        proxy = proxy[index + 3:]
 
         # Get username and password out.
         if '@' in proxy:
@@ -197,19 +232,12 @@ class ButterflyConnection(telepathy.server.Connection,
         else:
             user = password = None
 
-        server, port = proxy.split(':')
+        if ':' in proxy:
+            server, port = proxy.split(':')
 
-        self._proxies['http'] = \
-            papyon.ProxyInfos(host=server, port=int(port), type='http',
+        return papyon.ProxyInfos(host=server, port=int(port), type=ptype,
                 user=user, password=password)
 
-        if user:
-            logger.info('Using proxy: http://%s:***@%s:%u' % (user, server, int(port)))
-        else:
-            logger.info('Using proxy: http://%s:%u' % (server, int(port)))
-
-        return True
-
     @property
     def manager(self):
         return self._manager
@@ -381,11 +409,10 @@ class ButterflyConnection(telepathy.server.Connection,
             # connect to HTTP if we're already connected and we lose
             # connectivity (see fd.o#26147).
             if self._status == telepathy.CONNECTION_STATUS_CONNECTING and \
-                    (self._tried_http is False or \
-                   (self._tried_http is True and self._use_next_proxy())):
+                    self._use_next_proxy():
                 logger.info("Failed to connect, trying HTTP "
                             "(possibly again with another proxy)")
-                self._new_client(use_http=True)
+                self._new_client(use_http=self._try_http)
                 self._msn_client.login(*self._account)
             else:
                 self.__disconnect_reason = telepathy.CONNECTION_STATUS_REASON_NETWORK_ERROR
@@ -420,29 +447,27 @@ class ButterflyConnection(telepathy.server.Connection,
 
     # papyon.event.InviteEventInterface
     def on_invite_conference(self, call):
-        logger.debug("Call invite, ignoring it")
-        #logger.debug("Call invite")
-        #handle = ButterflyHandleFactory(self, 'contact', call.peer.account,
-                #call.peer.network_id)
+        logger.debug("Call invite")
+        handle = ButterflyHandleFactory(self, 'contact', call.peer.account,
+                call.peer.network_id)
 
-        #props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
-                #handle, False, initiator_handle=handle)
+        props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
+                handle, False, initiator_handle=handle)
 
-        #channel = self._channel_manager.channel_for_props(props,
-                #signal=True, call=call)
+        channel = self._channel_manager.channel_for_props(props,
+                signal=True, call=call)
 
     # papyon.event.InviteEventInterface
     def on_invite_webcam(self, session, producer):
         direction = (producer and "send") or "receive"
-        logger.debug("Invitation to %s webcam, ignoring it" % direction)
-        #logger.debug("Invitation to %s webcam" % direction)
+        logger.debug("Invitation to %s webcam" % direction)
 
-        #handle = ButterflyHandleFactory(self, 'contact', session.peer.account,
-                #session.peer.network_id)
-        #props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
-                #handle, False, initiator_handle=handle)
-        #channel = self._channel_manager.channel_for_props(props, signal=True,
-                #call=session)
+        handle = ButterflyHandleFactory(self, 'contact', session.peer.account,
+                session.peer.network_id)
+        props = self._generate_props(telepathy.CHANNEL_TYPE_STREAMED_MEDIA,
+                handle, False, initiator_handle=handle)
+        channel = self._channel_manager.channel_for_props(props, signal=True,
+                call=session)
 
     # papyon.event.OfflineMessagesEventInterface
     def on_oim_messages_received(self, messages):
