@@ -84,7 +84,7 @@ class ButterflyConnectionManager(telepathy.server.ConnectionManager):
 
     def quit(self):
         "Terminates all connections. Must be called upon quit"
-        conns = self._connections[:]
+        conns = self._connections.copy()
         for connection in conns:
             connection.Disconnect()
         logger.info("Connection manager quitting")
